"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useLoaderApi = void 0;
const react_1 = require("react");
function useLoaderApi() {
    const { current: loaders } = (0, react_1.useRef)(new Set());
    const [isLoading, setIsLoading] = (0, react_1.useState)(false);
    const reevaluate = (0, react_1.useCallback)(() => {
        // setState hook does not trigger re-render
        // unless value differs
        setIsLoading(loaders.size > 0);
    }, [loaders]);
    const api = (0, react_1.useMemo)(() => ({
        isActive: (id) => loaders.has(id),
        update: (id, value) => {
            const res = value ? !!loaders.add(id) : loaders.delete(id);
            reevaluate();
            return res;
        },
        remove: (id) => {
            const res = loaders.delete(id);
            reevaluate();
            return res;
        },
    }), [loaders, reevaluate]);
    return [api, isLoading];
}
exports.useLoaderApi = useLoaderApi;
//# sourceMappingURL=use-loader-api.js.map